# Hardwire options here
%define skip_nosrc 1

# Set the version number here.
%define ACEVER	5.6.1
%define TAOVER	1.6.1
%define CIAOVER	0.6.1
# Set is_major_ver if the version is X.Y insteasd X.Y.Z

# Conditional build
# Default values are --without guilibs (fltk, tk ,xt and qt support)
#                    --with rnq        (ACE_HAS_REACTOR_NOTIFICATION_QUEUE)
#                    --with ipv6       (IPv6 support)
#                    --with opt        (Optimized build)

#
# Read: If neither macro exists, then add the default definition.
%{!?_with_guilibs: %{!?_without_guilibs: %define _without_guilibs --without-guilibs}}
%{!?_with_rnq: %{!?_without_rnq: %define _with_rnq --with-rnq}}
%{!?_with_ipv6: %{!?_without_ipv6: %define _with_ipv6 --with-ipv6}}
%{!?_with_opt: %{!?_without_opt: %define _with_opt --with-opt}}
#
# Read: It's an error if both or neither required options exist.
%{?_with_guilibs: %{?_without_guilibs: %{error: both _with_guilibs and _without_guilibs}}}
%{?_with_rnq: %{?_without_rnq: %{error: both _with_rnq and _without_rnq}}}
%{?_with_ipv6: %{?_without_ipv6: %{error: both _with_ipv6 and _without_ipv6}}}
%{?_with_opt: %{?_without_opt: %{error: both _with_opt and _without_opt}}}

%{!?skip_make:%define skip_make 0}
%{!?skip_nosrc:%define skip_nosrc 0}
%{!?is_major_ver:%define is_major_ver 0}

# I think Mandrake sets this to .bz2, but Fedora doesn't seem to set it
%{!?_extension:%define _extension .gz}

Summary: The ADAPTIVE Communication Environment (ACE) and The ACE ORB (TAO)
Name: ace-tao
Version: %{ACEVER}
Release: 1
Group: Development/Libraries
URL: http://www.cs.wustl.edu/~schmidt/ACE.html
License: ACE License
Source0: http://deuce.doc.wustl.edu/old_distribution/ACE+TAO+CIAO-%{ACEVER}.tar.bz2
Source1: ace-tao-etc.tar.gz
Source2: ace-tao-macros.patch
Patch0: ace-tao-config.patch
%if %{?_with_ipv6:1}%{!?_with_ipv6:0}
Patch1: ace-tao-config-ipv6.patch
%endif
%if %{?_with_rnq:1}%{!?_with_rnq:0}
Patch2: ace-tao-rnq.patch
%endif
Patch3: ace-tao-codeset.patch
Patch4: ace-tao-gperf-info.patch
Patch6: ace-tao-x86_64.patch
# Don't use Patch8 (ace-tao-sslverify.patch) until verified it is required.
Patch9: ace-tao-hasicmp.patch
Patch10: ace-tao-obstack.patch
Patch11: ace-tao-config-epoll.patch
Patch12: ace-tao-config-tmplvis.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Requires(post): /sbin/install-info, /sbin/install-info
Requires(preun):  /sbin/install-info
Requires(postun): /sbin/ldconfig

BuildRequires: openssl-devel
BuildRequires: gcc-c++

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
BuildRequires: perl
BuildRequires: fltk-devel
BuildRequires: qt-devel
BuildRequires: tcl-devel
BuildRequires: tk-devel
BuildRequires: tk
# The xorg package naming scheme changed, use specific files for now.
# old -> BuildRequires: xorg-x11-devel
# new -> BuildRequires: libX11-devel
# BuildRequires: %{_libdir}/libX11.so
# BuildRequires: %{_libdir}/libXt.so
%endif

%if ! %skip_nosrc
# Leave out the distro for now
NoSource: 0
%endif

%description

The ADAPTIVE Communication Environment (ACE) is a freely available,
open-source object-oriented (OO) framework that implements many core
patterns for concurrent communication software. ACE provides a rich
set of reusable C++ wrapper facades and framework components that
perform common communication software tasks across a range of OS
platforms. The communication software tasks provided by ACE include
event demultiplexing and event handler dispatching, signal handling,
service initialization, interprocess communication, shared memory
management, message routing, dynamic (re)configuration of distributed
services, concurrent execution and synchronization.

TAO is a real-time implementation of CORBA built using the framework
components and patterns provided by ACE. TAO contains the network
interface, OS, communication protocol, and CORBA middleware components
and features. TAO is based on the standard OMG CORBA reference model,
with the enhancements designed to overcome the shortcomings of
conventional ORBs for high-performance and real-time applications.

# ---------------- ace ----------------

%package -n ace
Summary: The ADAPTIVE Communication Environment (ACE)
Version: %{ACEVER}
Group: Development/Libraries
Requires: openssl

%description -n ace

The ADAPTIVE Communication Environment (ACE) is a freely available,
open-source object-oriented (OO) framework that implements many core
patterns for concurrent communication software. ACE provides a rich
set of reusable C++ wrapper facades and framework components that
perform common communication software tasks across a range of OS
platforms. The communication software tasks provided by ACE include
event demultiplexing and event handler dispatching, signal handling,
service initialization, interprocess communication, shared memory
management, message routing, dynamic (re)configuration of distributed
services, concurrent execution and synchronization.

# ---------------- ace-devel ----------------

%package -n ace-devel
Summary: Header files and development components for ACE
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}
Requires: openssl-devel

%description -n ace-devel

This package contains the components needed for developing programs
using ACE.

# ---------------- ace-xml ----------------

%package -n ace-xml
Summary:  ACEXML
Version:  %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}

%description -n ace-xml

ACE XML Parser interfaces follows the the design of SAX 2.0, which is
a public domain specification for Java.  The major difference between
ACE XML Parser interfaces and SAX is that we added an reference of
ACEXML_Env to every SAX method to accomodate platforms/compilers that
don't support C++ exceptions.  SAX is defined by David Megginson
<david@megginson.com>

# ---------------- ace-xml-devel ----------------

%package -n ace-xml-devel
Summary:  ACEXML-devel
Version:  %{ACEVER}
Group: Development/Libraries
Requires: ace-devel = %{ACEVER}
Requires: ace-xml = %{ACEVER}

%description -n ace-xml-devel

This package contains the components needed for developing programs
using ACEXML.

# ---------------- ace-kokyu ----------------

%package -n ace-kokyu
Summary: Kokyu
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}

%description -n ace-kokyu

Kokyu is a portable middleware scheduling framework designed to
provide flexible scheduling and dispatching services within the
context of higher-level middleware. Kokyu currently provides real-time
scheduling and dispatching services for TAO's real-time Event Service
which mediates supplier-consumer relationships between application
operations. Kokyu also provides a scheduling and dispatching framework
for threads. This is being used by the TAO RTCORBA 2.0 scheduler
implementations.

# ---------------- ace-kokyu-devel ----------------

%package -n ace-kokyu-devel
Summary: kokyu-devel
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace-devel = %{ACEVER}
Requires: ace-kokyu = %{ACEVER}

%description -n ace-kokyu-devel

This package contains the components needed for developing programs
using Kokyu.


# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- ace-flreactor ----------------

%package -n ace-flreactor
Summary: ACE_FlReactor for use with the Fast-Light toolkit.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}
Requires: fltk

%description -n ace-flreactor

A Reactor implementation that uses the Fast-Light (FL) toolkit for
event demultiplexing.  This will let us integrate the FL toolkit with
ACE and/or TAO.

# ---------------- ace-flreactor-devel ----------------

%package -n ace-flreactor-devel
Summary: Header files for development with ACE_FlReactor.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace-devel = %{ACEVER}
Requires: ace-flreactor = %{ACEVER}
Requires: fltk-devel

%description -n ace-flreactor-devel

This package contains the components needed for developing programs
using the ACE_FlReactor.

# ---------------- ace-qtreactor ----------------

%package -n ace-qtreactor
Summary: ACE_QtReactor for use with Qt library.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}
Requires: qt

%description -n ace-qtreactor

A Reactor implementation that uses the Qt toolkit for event
demultiplexing.  This will let us integrate the Qt toolkit with ACE
and/or TAO.

# ---------------- ace-qtreactor-devel ----------------

%package -n ace-qtreactor-devel
Summary: Header files for development with ACE_QtReactor.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace-devel = %{ACEVER}
Requires: ace-qtreactor = %{ACEVER}
Requires: qt-devel

%description -n ace-qtreactor-devel

This package contains the components needed for developing programs
using the ACE_QtReactor.

# ---------------- ace-tkreactor ----------------

%package -n ace-tkreactor
Summary: ACE_TkReactor for use with Tk toolkit.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}
Requires: tk

%description -n ace-tkreactor

A Reactor implementation that uses the Tk toolkit for event
demultiplexing.  This will let us integrate the Tk toolkit with ACE
and/or TAO.

# ---------------- ace-tkreactor-devel ----------------

%package -n ace-tkreactor-devel
Summary: Header files for development with ACE_TkReactor.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace-devel = %{ACEVER}
Requires: ace-tkreactor = %{ACEVER}
Requires: tk-devel

%description -n ace-tkreactor-devel

This package contains the components needed for developing programs
using the ACE_TkReactor.

# ---------------- ace-xtreactor ----------------

%package -n ace-xtreactor
Summary: ACE_XtReactor for use with the X Toolkit.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}
# The xorg packaging scheme changed, let autoreq to the job for now.
# Requires: xorg-x11-libs

%description -n ace-xtreactor

A Reactor implementation that uses the X Toolkit for event
demultiplexing.  This will let us integrate the X Toolkit with ACE
and/or TAO.

# ---------------- ace-xtreactor-devel ----------------

%package -n ace-xtreactor-devel
Summary: Header files for development with ACE_XtReactor.
Version: %{ACEVER}
Group: Development/Libraries
Requires: ace-devel = %{ACEVER}
Requires: ace-xtreactor = %{ACEVER}
# The xorg package naming scheme changed, use specific files for now.
# old -> Requires: xorg-x11-devel
# new -> Requires: libX11-devel
Requires: %{_libdir}/libX11.so
Requires: %{_libdir}/libXt.so

%description -n ace-xtreactor-devel

This package contains the components needed for developing programs
using the ACE_XtReactor.
%endif

## FIXME - namespace issues need to be resolved
## 
## # ---------------- MPC ----------------
## 
## %package -n ace-mpc
## Summary: Make Project Creator
## Version: %{ACEVER}
## Group: Development/Libraries
## 
## %description -n ace-mpc
## 
## The Makefile, Project and Workspace Creator.
## Designed by Justin Michel (michel_j@ociweb.com) and Chad Elliott.
## Implemented by Chad Elliott (elliott_c@ociweb.com).
## 
## A single tool (MPC) can be used to generate tool specific input (i.e.
## Makefile, dsp, vcproj, etc). The generator takes platform and building
## tool generic files (mpc files) as input which describe basic information
## needed to generate a "project" file for various build tools. These tools
## include Make, NMake, Visual C++ 6, Visual C++ 7, etc.

# ---------------- tao ----------------

%package -n tao
Summary: The ACE ORB (TAO)
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace = %{ACEVER}
Requires: ace-xml = %{ACEVER}
Requires: ace-kokyu = %{ACEVER}

%description -n tao

TAO is a real-time implementation of CORBA built using the framework
components and patterns provided by ACE. TAO contains the network
interface, OS, communication protocol, and CORBA middleware components
and features. TAO is based on the standard OMG CORBA reference model,
with the enhancements designed to overcome the shortcomings of
conventional ORBs for high-performance and real-time applications.

# ---------------- tao-devel ----------------

%package -n tao-devel
Summary: Header files and development components for TAO
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}
Requires: ace-devel = %{ACEVER}
Requires: ace-xml-devel = %{ACEVER}
Requires: ace-kokyu-devel = %{ACEVER}

%description -n tao-devel

This package contains the components needed for developing programs
using TAO.

# ---------------- tao-naming ----------------

%package -n tao-naming
Summary: The TAO CORBA Naming Service (CosNaming) and Interoperable Naming Service (INS)
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}

%description -n tao-naming

OMG defined CORBA Naming Service to provide a basic service location
mechanism for CORBA systems. CosNaming manages a hierarchy of
name-to-object-reference mappings. Anything, but typically the server
process hosting an object, may bind an object reference with a name in
the Naming Service by providing the name and object
reference. Interested parties (typically clients) can then use the
Naming Service to resolve a name to an object reference.

More recently, CORBA Naming Service was subsumed/extended by the CORBA
Interoperable Naming Service, a.k.a. INS. INS inherits all the
functionality from the original Naming Service specification in
addition to addressing some its shortcomings. In particular, INS
defines a standard way for clients and servers to locate the Naming
Service itself. It also allows the ORB to be administratively
configured for bootstrapping to services not set up with the orb at
install time.

# ---------------- tao-cosevent ----------------

%package -n tao-cosevent
Summary: The TAO CORBA CosEvent Service
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}

%description -n tao-cosevent

The CosEvent_Service is a COS compilant Event Service.

The service is registered with the naming service with the name
"CosEventService" . It exposes the <EventChannel> interface which can be
used by suppliers and consumers to send and receive events.

# ---------------- tao-notify ----------------

%package -n tao-notify
Summary: The TAO CORBA Notification Service
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}

%description -n tao-notify

The Notify_Service is a COS compilant Notification Service.

The Notify_Service executable starts up a Notification Service factory
and registers it with the Naming Service under the name
"NotifyEventChannelFactory"

# ---------------- tao-trading ----------------

%package -n tao-trading
Summary: The TAO CORBA Trading Service
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}

%description -n tao-trading

The Trading_Service is a COS compilant Trading Service.

# ---------------- tao-event ----------------

%package -n tao-event
Summary: The TAO CORBA Event Service
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}

%description -n tao-event

The CORBA Event Service.

# ---------------- tao-concurrency ----------------

%package -n tao-concurrency
Summary: The TAO CORBA Concurrency Service
Version: %{TAOVER}
Group: Development/Libraries
Requires: tao = %{TAOVER}

%description -n tao-concurrency

The CORBA Concurrency Service.

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- tao-flresource ----------------

%package -n tao-flresource
Summary: FlResource_Factory for creating FlReactor.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-flreactor = %{ACEVER}
Requires: tao = %{TAOVER}

%description -n tao-flresource

This factory is intended for creating FlReactor for ORB. This factory
can be feed into ORB using TAO_ORB_Core::set_gui_resource_factory
method which is usually done by TAO_FlResource_Loader.

# ---------------- tao-flresource-devel ----------------

%package -n tao-flresource-devel
Summary: Header files for development with FlResource_Factory.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-flreactor-devel = %{ACEVER}
Requires: tao-devel = %{TAOVER}

%description -n tao-flresource-devel

This package contains the components needed for developing programs
using the FlResource_Factory.

# ---------------- tao-qtresource ----------------

%package -n tao-qtresource
Summary: QtResource_Factory for creating QtReactor.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-qtreactor = %{ACEVER}
Requires: tao = %{TAOVER}

%description -n tao-qtresource

This factory is intended for creating QtReactor for ORB. This factory
can be feed into ORB using TAO_ORB_Core::set_gui_resource_factory
method which is usually done by TAO_QtResource_Loader.

# ---------------- tao-qtresource-devel ----------------

%package -n tao-qtresource-devel
Summary: Header files for development with QtResource_Factory.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-qtreactor-devel = %{ACEVER}
Requires: tao-devel = %{TAOVER}

%description -n tao-qtresource-devel

This package contains the components needed for developing programs
using the QtResource_Factory.

# ---------------- tao-tkresource ----------------

%package -n tao-tkresource
Summary: TkResource_Factory for creating TkReactor.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-tkreactor = %{ACEVER}
Requires: tao = %{TAOVER}

%description -n tao-tkresource

This factory is intended for creating TkReactor for ORB. This factory
can be feed into ORB using TAO_ORB_Core::set_gui_resource_factory
method which is usually done by TAO_TkResource_Loader.

# ---------------- tao-tkresource-devel ----------------

%package -n tao-tkresource-devel
Summary: Header files for development with TkResource_Factory.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-tkreactor-devel = %{ACEVER}
Requires: tao-devel = %{TAOVER}

%description -n tao-tkresource-devel

This package contains the components needed for developing programs
using the TkResource_Factory.

# ---------------- tao-xtresource ----------------

%package -n tao-xtresource
Summary: XtResource_Factory for creating XtReactor.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-xtreactor = %{ACEVER}
Requires: tao = %{TAOVER}

%description -n tao-xtresource

This factory is intended for creating XtReactor for ORB. This factory
can be feed into ORB using TAO_ORB_Core::set_gui_resource_factory
method which is usually done by TAO_XtResource_Loader.

# ---------------- tao-xtresource-devel ----------------

%package -n tao-xtresource-devel
Summary: Header files for development with XtResource_Factory.
Version: %{TAOVER}
Group: Development/Libraries
Requires: ace-xtreactor-devel = %{ACEVER}
Requires: tao-devel = %{TAOVER}

%description -n tao-xtresource-devel

This package contains the components needed for developing programs
using the XtResource_Factory.
%endif

# ================================================================
# prep
# ================================================================

%prep
%setup -q -n ACE_wrappers

%if ! %skip_make

# patch0 and patch1 are applied a bit later
%patch3 -p 1
%patch4 -p 1

# 64 bit platforms need some paths patched.
%ifarch x86_64 ia64 ppc64 s390x
%patch6 -p 1
%endif

# don't use patch8 until we verify wether needed

export ACE_ROOT=`pwd`
export TAO_ROOT=$ACE_ROOT/TAO
export CIAO_ROOT=$TAO_ROOT/CIAO

# config.h
( cd $ACE_ROOT/ace
rm -f config.h
cp config-linux.h config.h
)

%patch0 -p 1

%if %{?_with_ipv6:1}%{!?_with_ipv6:0}
%patch1 -p 1
%endif

%if %{?_with_rnq:1}%{!?_with_rnq:0}
%patch2 -p 1
%endif

%patch9 -p 1
%patch10 -p 1
%patch11 -p 1
%patch12 -p 1

# platform_macros.GNU
cat > $ACE_ROOT/include/makeinclude/platform_macros.GNU <<EOF
ssl = 1
include \$(ACE_ROOT)/include/makeinclude/platform_linux.GNU
EOF

%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
cat >> $ACE_ROOT/include/makeinclude/platform_macros.GNU <<EOF
x11 = 1
xt = 1
tk = 1
fl = 1
qt = 1
gl = 1
ace_qtreactor = 1
ace_xtreactor = 1
ace_tkreactor = 1
ace_flreactor = 1
tao_qtresource = 1
tao_xtresource = 1
tao_tkresource = 1
tao_flresource = 1
EOF
%endif

# 64 bit machines need additional macro.
%ifarch x86_64 ia64 ppc64 s390x
cat >> $ACE_ROOT/include/makeinclude/platform_macros.GNU <<EOF
buildbits = 64 
EOF
%endif

%if %{?_with_opt:0}%{!?_with_opt:1}
cat >> $ACE_ROOT/include/makeinclude/platform_macros.GNU <<EOF
# Disable optimization
OCFLAGS = -O0
EOF
%endif

cat > $ACE_ROOT/bin/MakeProjectCreator/config/default.features <<EOF
ssl=1
qos=0
cidl=0
rwho=0
sctp=0
EOF

# We don't use default.features to enable ipv6 cause it conflicts w/
# the config.h generated version.  Config.h is superior because it is
# shipped to the end-user machines and also defines
# ACE_USES_IPV4_IPV6_MIGRATION which the default.features technique
# does not seem to set.

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
cat >> $ACE_ROOT/bin/MakeProjectCreator/config/default.features <<EOF
motif=1
athena=1
x11=1
xt=1
tk=1
fl=1
qt=1
gl=1
ace_qtreactor=1
ace_xtreactor=1
ace_tkreactor=1
ace_flreactor=1
tao_qtresource=1
tao_xtresource=1
tao_tkresource=1
tao_flresource=1
EOF
%endif

# Need to regenerate all of the Makefiles ...
(cd $ACE_ROOT && $ACE_ROOT/bin/mwc.pl -type gnuace)

# Create a symbolic link so tao_idl can refer to gperf as gperf-ace
ln -s ${ACE_ROOT}/bin/gperf ${ACE_ROOT}/bin/gperf-ace

# Fix source file permissions
find $TAO_ROOT/orbsvcs/FT_ReplicationManager -type f -exec chmod a-x {} \;
find $TAO_ROOT/orbsvcs/orbsvcs/FaultTolerance -type f -exec chmod a-x {} \;

%endif

# ================================================================
# build
# ================================================================

%build

export ACE_ROOT=`pwd`
export TAO_ROOT=$ACE_ROOT/TAO
export LD_LIBRARY_PATH=$ACE_ROOT/lib

%if %skip_make
cd .. && rm -rf ACE_wrappers && ln -s ACE_wrappers-BUILT ACE_wrappers
%else
MAKECMD="make %{?_smp_mflags}"

# build ACE components
for ace_comp in \
    ace \
    Kokyu \
    ACEXML \
    apps/gperf \
    protocols \
    websvcs; do (
$MAKECMD -C $ACE_ROOT/$ace_comp
); done

# build TAO components
$MAKECMD -C $TAO_ROOT/TAO_IDL
$MAKECMD -C $TAO_ROOT/tao

# Instead of "$MAKECMD -C $TAO_ROOT/orbsvcs" use the list from
# $ACE_ROOT/orbsvcs/GNUmakefile less the performance-tests, tests and
# examples.
for orbsvcs_comp in \
    PSS \
    TAO_Service \
    orbsvcs \
    Trading_Service \
    Time_Service \
    Scheduling_Service \
    Notify_Service \
    Naming_Service \
    Logging_Service \
    LoadBalancer \
    LifeCycle_Service \
    ImplRepo_Service \
    IFR_Service \
    Fault_Notifier \
    Fault_Detector \
    FT_ReplicationManager \
    FTRT_Event_Service \
    Event_Service \
    Dump_Schedule \
    CosEvent_Service \
    Concurrency_Service; do (
$MAKECMD -C $TAO_ROOT/orbsvcs/$orbsvcs_comp
); done

$MAKECMD -C $TAO_ROOT/utils

%endif

# ================================================================
# install
# ================================================================

# For major releases the package version will be the shortened version
# tuple and the shared-object version needs a placeholder '.0'
%if %is_major_ver
%define ACEVERSO %{ACEVER}.0
%define TAOVERSO %{TAOVER}.0
%define CIAOVERSO %{CIAOVER}.0
%else
%define ACEVERSO %{ACEVER}
%define TAOVERSO %{TAOVER}
%define CIAOVERSO %{CIAOVER}
%endif

%install

export ACE_ROOT=`pwd`
export TAO_ROOT=$ACE_ROOT/TAO

%if ! %skip_make
cat %{SOURCE2} | patch -p 1
%endif

rm -rf $RPM_BUILD_ROOT

# make a new build root dir
mkdir -p $RPM_BUILD_ROOT

# ---------------- Runtime Components ----------------

# install shared libraries
install -d $RPM_BUILD_ROOT%{_libdir}

# ACE + XML libraries
INSTLIBS=`ls ${ACE_ROOT}/lib/libACE*.so.%{ACEVERSO}`
install $INSTLIBS $RPM_BUILD_ROOT%{_libdir}

# ACE-Kokyu libraries
INSTLIBS=`ls ${ACE_ROOT}/lib/libKokyu.so.%{ACEVERSO}`
install $INSTLIBS $RPM_BUILD_ROOT%{_libdir}

# TAO libraries
INSTLIBS=`ls ${ACE_ROOT}/lib/libTAO*.so.%{TAOVERSO}`
install $INSTLIBS $RPM_BUILD_ROOT%{_libdir}

# Create un-versioned symbolic links for libraries
(cd $RPM_BUILD_ROOT%{_libdir} && \
 ls *.so.* | awk 'BEGIN{FS="."}{print "ln -sf " $0 " " $1 "." $2;}' | sh)

# install binaries
install -d $RPM_BUILD_ROOT%{_bindir}

for svc in \
    Naming_Service \
    CosEvent_Service \
    Notify_Service \
    Trading_Service \
    Event_Service \
    Concurrency_Service; do (
install ${ACE_ROOT}/TAO/orbsvcs/$svc/$svc $RPM_BUILD_ROOT%{_bindir}
); done

# ---------------- Development Components ----------------

# INSTHDR="cp --preserve=timestamps"
INSTHDR="install -m 0644 -p"

# install headers
install -d $RPM_BUILD_ROOT%{_includedir}
( set +x
echo "Building list of headers..."

# Generate raw dependency output
BASEHDR=`find \
    ace \
    ACEXML/common \
    ACEXML/parser/parser \
    Kokyu \
    TAO/tao \
    TAO/orbsvcs/orbsvcs \
    -name '*.h' -not -name 'config-*'`
for j in $BASEHDR; do
	echo $j >> rawhdrs.log
	echo '#include <'$j'>' | \
	g++ -I . \
            -I protocols \
            -I TAO \
            -I TAO/orbsvcs \
            -I TAO/orbsvcs/orbsvcs \
            -x c++ - -MM -MF mmout 2>> rawhdrs.log && cat mmout || true;
done > mmraw.list

# Cleanup dependency output:
#   remove '-:' sequences
#   change all sequences of whitespace into \n
#   remove leading './'
#   cannonicalize up to two levels of '/../../'
#   remove duplicates
cat mmraw.list |\
	sed -e 's/^-://g' -e 's/\\//g' | \
	tr -s [:space:] "\n" | \
        sed -e 's#^./##g' | \
        sed -e 's#/[^/]\+/\.\./#/#g' -e 's#/[^/]\+/\.\./#/#g' | \
	sort -u > allhdrs.list

# Add missing headers.
echo ace/QtReactor/QtReactor.h >> allhdrs.list
echo TAO/tao/QtResource/QtResource_Factory.h >> allhdrs.list

# Install headers and create header lists
rm -f ace-headers.tmp
rm -f acexml-headers.tmp
rm -f kokyu-headers.tmp
rm -f tao-headers.tmp

for i in `cat allhdrs.list`; do
    case "$i" in
    protocols/ace/*)
	mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/${i/protocols\/}`
        $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/${i/protocols/}
	echo '%dir %{_includedir}/'`dirname ${i/protocols/}` >> ace-headers.tmp
        echo '%{_includedir}/'${i/protocols/} >> ace-headers.tmp
        ;;
    ace/*)
	mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/$i`
        $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/$i
	echo '%dir %{_includedir}/'`dirname $i` >> ace-headers.tmp
        echo '%{_includedir}/'$i >> ace-headers.tmp
        ;;
    ACEXML/*)
        mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/$i`
        $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/$i
	echo '%dir %{_includedir}/'`dirname $i` >> acexml-headers.tmp
        echo '%{_includedir}/'$i >> acexml-headers.tmp
        ;;
    Kokyu/*)
        mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/$i`
        $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/$i
	echo '%dir %{_includedir}/'`dirname $i` >> kokyu-headers.tmp
        echo '%{_includedir}/'$i >> kokyu-headers.tmp
        ;;
    TAO/tao/*)
        mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/${i/TAO\/}`
        $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/${i/TAO\/}
	echo '%dir %{_includedir}/'`dirname ${i/TAO\/}` >> tao-headers.tmp
        echo '%{_includedir}/'${i/TAO\/} >> tao-headers.tmp
        ;;
    TAO/orbsvcs/orbsvcs/*)
        mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/${i/TAO\/orbsvcs\/}`
        $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/${i/TAO\/orbsvcs\/}
	echo '%dir %{_includedir}/'`dirname ${i/TAO\/orbsvcs\/}` >> tao-headers.tmp
        echo '%{_includedir}/'${i/TAO\/orbsvcs\/} >> tao-headers.tmp
        ;;
    *)
        # mkdir -p `dirname $RPM_BUILD_ROOT%{_includedir}/$i`
        # $INSTHDR $i $RPM_BUILD_ROOT%{_includedir}/$i
	echo $i
        ;;
    esac
done

echo '%defattr(-,root,root,-)' > ace-headers.list
sort -u < ace-headers.tmp >> ace-headers.list
rm -f ace-headers.tmp

echo '%defattr(-,root,root,-)' > acexml-headers.list
sort -u < acexml-headers.tmp >> acexml-headers.list
rm -f acexml-headers.tmp

echo '%defattr(-,root,root,-)' > kokyu-headers.list
sort -u < kokyu-headers.tmp >> kokyu-headers.list
rm -f kokyu-headers.tmp

echo '%defattr(-,root,root,-)' > tao-headers.list
sort -u < tao-headers.tmp >> tao-headers.list
rm -f tao-headers.tmp
)

# install the TAO_IDL compiler
install -d $RPM_BUILD_ROOT%{_libdir}

# NOTE - it appears that when TAO's build copies the files to the
# ACE_ROOT/ace directory they get versioned with ACE's version number
# rather then TAO's.  Use the ACEVERSO macro for now ...
install \
	${ACE_ROOT}/lib/libTAO_IDL_BE.so.%{ACEVERSO} \
	${ACE_ROOT}/lib/libTAO_IDL_FE.so.%{ACEVERSO} \
	$RPM_BUILD_ROOT%{_libdir}

(cd $RPM_BUILD_ROOT%{_libdir} && ln -sf libTAO_IDL_BE.so.%{ACEVERSO} libTAO_IDL_BE.so)
(cd $RPM_BUILD_ROOT%{_libdir} && ln -sf libTAO_IDL_FE.so.%{ACEVERSO} libTAO_IDL_FE.so)

install -d $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/gperf $RPM_BUILD_ROOT%{_bindir}/gperf-ace
install ${ACE_ROOT}/bin/tao_idl $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/tao_imr $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/tao_ifr $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/catior $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/nsadd $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/nsdel $RPM_BUILD_ROOT%{_bindir}
install ${ACE_ROOT}/bin/nslist $RPM_BUILD_ROOT%{_bindir}

# ================================================================
# Config & Options
# ================================================================

install -d $RPM_BUILD_ROOT%{_sysconfdir}
tar xzvf %{SOURCE1} -C $RPM_BUILD_ROOT%{_sysconfdir}

## # FIXME - namespace issues need to be resolved
## 
## # ================================================================
## # Makefiles
## # ================================================================
## 
## install -d $RPM_BUILD_ROOT%{_includedir}/makeinclude
## 
## for mk_macros in \
##     all_in_one.GNU \
##     component_check.GNU \
##     macros.GNU \
##     platform_g++_common.GNU \
##     platform_linux.GNU \
##     platform_macros.GNU \
##     rules.bin.GNU \
##     rules.common.GNU \
##     rules.lib.GNU \
##     rules.local.GNU \
##     rules.nested.GNU \
##     rules.nolocal.GNU \
##     rules.nonested.GNU \
##     wrapper_macros.GNU; do (
## install ${ACE_ROOT}/include/makeinclude/$mk_macros $RPM_BUILD_ROOT%{_includedir}/makeinclude
## ); done
## 
## install ${TAO_ROOT}/rules.tao.GNU $RPM_BUILD_ROOT%{_includedir}/makeinclude
## 
## install -d $RPM_BUILD_ROOT%{_datadir}
## install -d $RPM_BUILD_ROOT%{_datadir}/ace
## install -d $RPM_BUILD_ROOT%{_datadir}/ace/MPC
## cp -a ${ACE_ROOT}/MPC $RPM_BUILD_ROOT%{_datadir}/ace/
## 
## install -d $RPM_BUILD_ROOT%{_datadir}/ace/bin
## cp -a ${ACE_ROOT}/bin/DependencyGenerator $RPM_BUILD_ROOT%{_datadir}/ace/bin
## cp -a ${ACE_ROOT}/bin/MakeProjectCreator $RPM_BUILD_ROOT%{_datadir}/ace/bin
## install -d $RPM_BUILD_ROOT%{_datadir}/ace/bin/PerlACE
## install ${ACE_ROOT}/bin/PerlACE/{ConfigList,Process,Process_Unix}.pm $RPM_BUILD_ROOT%{_datadir}/ace/bin/PerlACE
## install ${ACE_ROOT}/bin/mpc.pl $RPM_BUILD_ROOT%{_datadir}/ace/bin
## install ${ACE_ROOT}/bin/mwc.pl $RPM_BUILD_ROOT%{_datadir}/ace/bin
## install ${ACE_ROOT}/bin/g++dep $RPM_BUILD_ROOT%{_datadir}/ace/bin
## install ${ACE_ROOT}/bin/depgen.pl $RPM_BUILD_ROOT%{_datadir}/ace/bin
## install ${ACE_ROOT}/bin/generate_export_file.pl $RPM_BUILD_ROOT%{_datadir}/ace/bin
## install ${ACE_ROOT}/bin/{ACEutils,Process,Process_Unix,Uniqueid}.pm $RPM_BUILD_ROOT%{_datadir}/ace/bin

rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/profile.d

# ================================================================
# Manuals
# ================================================================
install -d $RPM_BUILD_ROOT%{_mandir}
install -d $RPM_BUILD_ROOT%{_mandir}/man1
install ${TAO_ROOT}/TAO_IDL/tao_idl.1 $RPM_BUILD_ROOT%{_mandir}/man1
install ${ACE_ROOT}/apps/gperf/gperf.1 $RPM_BUILD_ROOT%{_mandir}/man1/gperf-ace.1
install -d  $RPM_BUILD_ROOT%{_infodir}
install ${ACE_ROOT}/apps/gperf/gperf.info $RPM_BUILD_ROOT%{_infodir}/gperf-ace.info

# ================================================================
# Create lists of symlinked so's.  We need two lists because we need
# the unversioned symlinks in the runtime package for so's that can
# be loaded in the svc.conf.
# ================================================================

# Make a list of all shared objects.
(cd $RPM_BUILD_ROOT/%{_libdir} && ls *.so | \
	awk '{ print "%{_libdir}/"$1; }' | \
	sort) > all-so.list

# Make a list of likely svc.conf targets.
(cd $RPM_BUILD_ROOT/%{_libdir} && ls *.so | \
    nm --print-file-name *.so | \
    grep _make_ | \
    awk 'BEGIN { FS=":"} /^[^:]+:/ { print "%{_libdir}/"$1; }' | \
    sort -u) > rough-svc-so.list

# Remove false positives (IMPORTANT keep this list sorted!)
cat > falsepos-svc-so.list <<EOF
%{_libdir}/libACE.so
%{_libdir}/libTAO.so
EOF
comm -2 -3 rough-svc-so.list falsepos-svc-so.list > svc-so.list

# Find the list of non-sv.conf target files.
comm -2 -3 all-so.list svc-so.list > nonsvc-so.list

# Generate file lists.
grep libACE svc-so.list > ace-svc-so.list
grep libACE nonsvc-so.list > ace-nonsvc-so.list
grep libTAO svc-so.list > tao-svc-so.list
grep libTAO nonsvc-so.list > tao-nonsvc-so.list

# Concatenate file lists as neccessary
cat tao-headers.list tao-nonsvc-so.list > tao-devel-files.list

# ================================================================
# clean
# ================================================================

%clean
rm -rf $RPM_BUILD_ROOT

# ================================================================
# pre install
# ================================================================

# ---------------- tao-naming ----------------

%pre -n tao-naming

/usr/sbin/groupadd -r tao  2> /dev/null || :
/usr/sbin/useradd -g tao -s /sbin/nologin -M -r -d %{_sysconfdir}/tao -c "TAO Services" tao 2>/dev/null || :

# ---------------- tao-cosevent ----------------

%pre -n tao-cosevent

/usr/sbin/groupadd -r tao  2> /dev/null || :
/usr/sbin/useradd -g tao -s /sbin/nologin -M -r -d %{_sysconfdir}/tao -c "TAO Services" tao 2>/dev/null || :

# ---------------- tao-notify ----------------

%pre -n tao-notify

/usr/sbin/groupadd -r tao  2> /dev/null || :
/usr/sbin/useradd -g tao -s /sbin/nologin -M -r -d %{_sysconfdir}/tao -c "TAO Services" tao 2>/dev/null || :

# ---------------- tao-trading ----------------

%pre -n tao-trading

/usr/sbin/groupadd -r tao  2> /dev/null || :
/usr/sbin/useradd -g tao -s /sbin/nologin -M -r -d %{_sysconfdir}/tao -c "TAO Services" tao 2>/dev/null || :

# ---------------- tao-event ----------------

%pre -n tao-event

/usr/sbin/groupadd -r tao  2> /dev/null || :
/usr/sbin/useradd -g tao -s /sbin/nologin -M -r -d %{_sysconfdir}/tao -c "TAO Services" tao 2>/dev/null || :

# ---------------- tao-concurrency ----------------

%pre -n tao-concurrency

/usr/sbin/groupadd -r tao  2> /dev/null || :
/usr/sbin/useradd -g tao -s /sbin/nologin -M -r -d %{_sysconfdir}/tao -c "TAO Services" tao 2>/dev/null || :

# ================================================================
# post install
# ================================================================

# ---------------- ace ----------------

%post -n ace

/sbin/ldconfig

# ---------------- ace-devel ----------------

%post -n ace-devel

/sbin/install-info %{_infodir}/gperf-ace.info%{_extension} %{_infodir}/dir

# ---------------- ace-xml ----------------

%post -n ace-xml

/sbin/ldconfig

# ---------------- ace-kokyu ----------------

%post -n ace-kokyu

/sbin/ldconfig

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- ace-flreactor ----------------

%post -n ace-flreactor

/sbin/ldconfig

# ---------------- ace-qtreactor ----------------

%post -n ace-qtreactor

/sbin/ldconfig

# ---------------- ace-tkreactor ----------------

%post -n ace-tkreactor

/sbin/ldconfig

# ---------------- ace-xtreactor ----------------

%post -n ace-xtreactor

/sbin/ldconfig
%endif

# ---------------- tao ----------------

%post -n tao

/sbin/ldconfig

# ---------------- tao-devel ----------------

%post -n tao-devel

/sbin/ldconfig

# ---------------- tao-naming ----------------

%post -n tao-naming

/sbin/chkconfig --add Naming_Service

mkdir -p /var/cache/tao
chown tao:tao /var/cache/tao

mkdir -p /var/log/tao
touch /var/log/tao/Naming_Service.log
chown tao:tao /var/log/tao/Naming_Service.log

# ---------------- tao-cosevent ----------------

%post -n tao-cosevent

/sbin/chkconfig --add CosEvent_Service

mkdir -p /var/cache/tao
chown tao:tao /var/cache/tao

mkdir -p /var/log/tao
touch /var/log/tao/CosEvent_Service.log
chown tao:tao /var/log/tao/CosEvent_Service.log

# ---------------- tao-notify ----------------

%post -n tao-notify

/sbin/chkconfig --add Notify_Service

mkdir -p /var/cache/tao
chown tao:tao /var/cache/tao

mkdir -p /var/log/tao
touch /var/log/tao/Notify_Service.log
chown tao:tao /var/log/tao/Notify_Service.log

# ---------------- tao-trading ----------------

%post -n tao-trading

/sbin/chkconfig --add Trading_Service

mkdir -p /var/cache/tao
chown tao:tao /var/cache/tao

mkdir -p /var/log/tao
touch /var/log/tao/Trading_Service.log
chown tao:tao /var/log/tao/Trading_Service.log

# ---------------- tao-event ----------------

%post -n tao-event

/sbin/chkconfig --add Event_Service

mkdir -p /var/cache/tao
chown tao:tao /var/cache/tao

mkdir -p /var/log/tao
touch /var/log/tao/Event_Service.log
chown tao:tao /var/log/tao/Event_Service.log

# ---------------- tao-concurrency ----------------

%post -n tao-concurrency

/sbin/chkconfig --add Concurrency_Service

mkdir -p /var/cache/tao
chown tao:tao /var/cache/tao

mkdir -p /var/log/tao
touch /var/log/tao/Concurrency_Service.log
chown tao:tao /var/log/tao/Concurrency_Service.log

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- tao-flresource ----------------

%post -n tao-flresource

/sbin/ldconfig

# ---------------- tao-qtresource ----------------

%post -n tao-qtresource

/sbin/ldconfig

# ---------------- tao-tkresource ----------------

%post -n tao-tkresource

/sbin/ldconfig

# ---------------- tao-xtresource ----------------

%post -n tao-xtresource

/sbin/ldconfig
%endif

# ================================================================
# pre uninstall
# ================================================================

# ---------------- ace-devel ----------------

%preun -n ace-devel

if [ $1 = 0 ]; then
    /sbin/install-info --delete %{_infodir}/gperf-ace.info.gz %{_infodir}/dir
fi

# ---------------- tao-naming ----------------

%preun -n tao-naming

if [ $1 = 0 ]; then
    /sbin/service Naming_Service stop > /dev/null 2>&1
    /sbin/chkconfig --del Naming_Service
fi

# ---------------- tao-cosevent ----------------

%preun -n tao-cosevent

if [ $1 = 0 ]; then
    /sbin/service CosEvent_Service stop > /dev/null 2>&1
    /sbin/chkconfig --del CosEvent_Service
fi

# ---------------- tao-notify ----------------

%preun -n tao-notify

if [ $1 = 0 ]; then
    /sbin/service Notify_Service stop > /dev/null 2>&1
    /sbin/chkconfig --del Notify_Service
fi

# ---------------- tao-trading ----------------

%preun -n tao-trading

if [ $1 = 0 ]; then
    /sbin/service Trading_Service stop > /dev/null 2>&1
    /sbin/chkconfig --del Trading_Service
fi

# ---------------- tao-event ----------------

%preun -n tao-event

if [ $1 = 0 ]; then
    /sbin/service Event_Service stop > /dev/null 2>&1
    /sbin/chkconfig --del Event_Service
fi

# ---------------- tao-concurrency ----------------

%preun -n tao-concurrency

if [ $1 = 0 ]; then
    /sbin/service Concurrency_Service stop > /dev/null 2>&1
    /sbin/chkconfig --del Concurrency_Service
fi

# ================================================================
# post uninstall
# ================================================================

# ---------------- ace ----------------

%postun -n ace

/sbin/ldconfig

# ---------------- ace-xml ----------------

%postun -n ace-xml

/sbin/ldconfig

# ---------------- ace-kokyu ----------------

%postun -n ace-kokyu

/sbin/ldconfig

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- ace-flreactor ----------------

%postun -n ace-flreactor

/sbin/ldconfig

# ---------------- ace-qtreactor ----------------

%postun -n ace-qtreactor

/sbin/ldconfig

# ---------------- ace-tkreactor ----------------

%postun -n ace-tkreactor

/sbin/ldconfig

# ---------------- ace-xtreactor ----------------

%postun -n ace-xtreactor

/sbin/ldconfig
%endif

# ---------------- tao ----------------

%postun -n tao

/sbin/ldconfig

# ---------------- tao-devel ----------------

%postun -n tao-devel

/sbin/ldconfig

# ---------------- tao-naming ----------------

%postun -n tao-naming

if [ "$1" -ge "1" ]; then
    /sbin/service Naming_Service condrestart > /dev/null 2>&1
fi

# ---------------- tao-cosevent ----------------

%postun -n tao-cosevent

if [ "$1" -ge "1" ]; then
    /sbin/service CosEvent_Service condrestart > /dev/null 2>&1
fi

# ---------------- tao-notify ----------------

%postun -n tao-notify

if [ "$1" -ge "1" ]; then
    /sbin/service Notify_Service condrestart > /dev/null 2>&1
fi

# ---------------- tao-trading ----------------

%postun -n tao-trading

if [ "$1" -ge "1" ]; then
    /sbin/service Trading_Service condrestart > /dev/null 2>&1
fi

# ---------------- tao-event ----------------

%postun -n tao-event

if [ "$1" -ge "1" ]; then
    /sbin/service Event_Service condrestart > /dev/null 2>&1
fi

# ---------------- tao-concurrency ----------------

%postun -n tao-concurrency

if [ "$1" -ge "1" ]; then
    /sbin/service Concurrency_Service condrestart > /dev/null 2>&1
fi

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- tao-flresource ----------------

%postun -n tao-flresource

/sbin/ldconfig

# ---------------- tao-qtresource ----------------

%postun -n tao-qtresource

/sbin/ldconfig

# ---------------- tao-tkresource ----------------

%postun -n tao-tkresource

/sbin/ldconfig

# ---------------- tao-xtresource ----------------

%postun -n tao-xtresource

/sbin/ldconfig
%endif

# ================================================================
# files
# ================================================================

# ---------------- ace ----------------

%files -n ace
%defattr(-,root,root,-)
%doc ACE-INSTALL.html
%doc AUTHORS
%doc COPYING
%doc FAQ
%doc PROBLEM-REPORT-FORM
%doc README
%doc THANKS
%doc VERSION
%{_libdir}/libACE.so.%{ACEVERSO}
%{_libdir}/libACE_HTBP.so.%{ACEVERSO}
%{_libdir}/libACE_RMCast.so.%{ACEVERSO}
%{_libdir}/libACE_SSL.so.%{ACEVERSO}
%{_libdir}/libACE_TMCast.so.%{ACEVERSO}

# ---------------- ace-devel ----------------

%files -n ace-devel -f ace-headers.list
%defattr(-,root,root,-)
%{_bindir}/gperf-ace
%{_libdir}/libACE.so
%{_libdir}/libACE_HTBP.so
%{_libdir}/libACE_RMCast.so
%{_libdir}/libACE_SSL.so
%{_libdir}/libACE_TMCast.so
%attr(0644,root,root) %{_mandir}/man1/gperf-ace.1%{_extension}
%attr(0644,root,root) %{_infodir}/gperf-ace.info%{_extension}

%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
%exclude %{_includedir}/ace/FlReactor/FlReactor.h
%exclude %{_includedir}/ace/FlReactor/ACE_FlReactor_export.h
%exclude %{_includedir}/ace/QtReactor/QtReactor.h
%exclude %{_includedir}/ace/QtReactor/ACE_QtReactor_export.h
%exclude %{_includedir}/ace/TkReactor/TkReactor.h
%exclude %{_includedir}/ace/TkReactor/ACE_TkReactor_export.h
%exclude %{_includedir}/ace/XtReactor/XtReactor.h
%exclude %{_includedir}/ace/XtReactor/ACE_XtReactor_export.h
%endif

# ---------------- ace-xml ----------------

%files -n ace-xml
%defattr(-,root,root,-)
%{_libdir}/libACEXML*.so.%{ACEVERSO}

# ---------------- ace-xml-devel ----------------

%files -n ace-xml-devel -f acexml-headers.list
%defattr(-,root,root,-)
%{_libdir}/libACEXML*.so

# These get missed by the automatic list generator because they
# contain no immediate files.
%dir %{_includedir}/ACEXML/parser
%dir %{_includedir}/ACEXML

# ---------------- ace-kokyu ----------------

%files -n ace-kokyu
%defattr(-,root,root,-)
%{_libdir}/libKokyu.so.%{ACEVERSO}

# ---------------- ace-kokyu-devel ----------------

%files -n ace-kokyu-devel -f kokyu-headers.list
%defattr(-,root,root,-)
%{_libdir}/libKokyu.so

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- ace-flreactor ----------------
%files -n ace-flreactor
%defattr(-,root,root,-)
%{_libdir}/libACE_FlReactor.so.%{ACEVERSO}

# ---------------- ace-flreactor-devel ----------------
%files -n ace-flreactor-devel
%defattr(-,root,root,-)
%dir %{_includedir}/ace/FlReactor
%{_libdir}/libACE_FlReactor.so
%{_includedir}/ace/FlReactor/FlReactor.h
%{_includedir}/ace/FlReactor/ACE_FlReactor_export.h

# ---------------- ace-qtreactor ----------------
%files -n ace-qtreactor
%defattr(-,root,root,-)
%{_libdir}/libACE_QtReactor.so.%{ACEVERSO}

# ---------------- ace-qtreactor-devel ----------------
%files -n ace-qtreactor-devel
%defattr(-,root,root,-)
%{_libdir}/libACE_QtReactor.so
%dir %{_includedir}/ace/QtReactor
%{_includedir}/ace/QtReactor/QtReactor.h
%{_includedir}/ace/QtReactor/ACE_QtReactor_export.h

# ---------------- ace-tkreactor ----------------
%files -n ace-tkreactor
%defattr(-,root,root,-)
%{_libdir}/libACE_TkReactor.so.%{ACEVERSO}

# ---------------- ace-tkreactor-devel ----------------
%files -n ace-tkreactor-devel
%defattr(-,root,root,-)
%{_libdir}/libACE_TkReactor.so
%dir %{_includedir}/ace/TkReactor
%{_includedir}/ace/TkReactor/TkReactor.h
%{_includedir}/ace/TkReactor/ACE_TkReactor_export.h

# ---------------- ace-xtreactor ----------------
%files -n ace-xtreactor
%defattr(-,root,root,-)
%{_libdir}/libACE_XtReactor.so.%{ACEVERSO}

# ---------------- ace-xtreactor-devel ----------------
%files -n ace-xtreactor-devel
%defattr(-,root,root,-)
%{_libdir}/libACE_XtReactor.so
%dir %{_includedir}/ace/XtReactor
%{_includedir}/ace/XtReactor/XtReactor.h
%{_includedir}/ace/XtReactor/ACE_XtReactor_export.h
%endif

## FIXME - namespace issues need to be resolved
##
## # ---------------- ace-mpc ----------------
## %files -n ace-mpc
## %defattr(-,root,root,-)
## %{_sysconfdir}/profile.d
## %{_datadir}/ace

# ---------------- tao ----------------

%files -n tao -f tao-svc-so.list
%defattr(-,root,root,-)
%doc TAO/COPYING
%doc TAO/PROBLEM-REPORT-FORM
%doc TAO/TAO-INSTALL.html
%doc TAO/VERSION
%doc TAO/README

%{_libdir}/libTAO*.so.%{TAOVERSO}

# The libTAO_IFR_BE needs the IDL front-end
%{_libdir}/libTAO_IDL_FE.so.%{ACEVERSO}

%exclude %{_libdir}/libTAO_IDL_BE*

%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
%exclude %{_libdir}/libTAO_FlResource.so*
%exclude %{_libdir}/libTAO_QtResource.so*
%exclude %{_libdir}/libTAO_TkResource.so*
%exclude %{_libdir}/libTAO_XtResource.so*
%endif

# ---------------- tao-devel ----------------

%files -n tao-devel -f tao-devel-files.list
%defattr(-,root,root,-)

%{_libdir}/libTAO_IDL_BE.so.%{ACEVERSO}

%{_bindir}/tao_idl
%{_bindir}/tao_imr
%{_bindir}/tao_ifr
%{_bindir}/catior
%{_bindir}/nsadd
%{_bindir}/nsdel
%{_bindir}/nslist
%attr(0644,root,root) %{_mandir}/man1/tao_idl.1%{_extension}

# These get missed by the automatic list generator because they
# contain no immediate files.
%dir %{_includedir}/orbsvcs/FtRtEvent

%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
%exclude %{_includedir}/tao/FlResource/FlResource_Factory.h
%exclude %{_includedir}/tao/FlResource/FlResource_Loader.h
%exclude %{_includedir}/tao/FlResource/TAO_FlResource_Export.h
%exclude %{_includedir}/tao/QtResource/QtResource_Factory.h
%exclude %{_includedir}/tao/QtResource/QtResource_Loader.h
%exclude %{_includedir}/tao/QtResource/TAO_QtResource_Export.h
%exclude %{_includedir}/tao/TkResource/TkResource_Factory.h
%exclude %{_includedir}/tao/TkResource/TkResource_Loader.h
%exclude %{_includedir}/tao/TkResource/TAO_TkResource_Export.h
%exclude %{_includedir}/tao/XtResource/XtResource_Factory.h
%exclude %{_includedir}/tao/XtResource/XtResource_Loader.h
%exclude %{_includedir}/tao/XtResource/TAO_XtResource_Export.h
%exclude %{_libdir}/libTAO_FlResource.so
%exclude %{_libdir}/libTAO_QtResource.so
%exclude %{_libdir}/libTAO_TkResource.so
%exclude %{_libdir}/libTAO_XtResource.so
%endif

# ---------------- tao-naming ----------------

%files -n tao-naming
%defattr(-,root,root,-)

%{_bindir}/Naming_Service
%config %{_sysconfdir}/rc.d/init.d/Naming_Service
%dir %{_sysconfdir}/tao
%config(noreplace) %{_sysconfdir}/tao/Naming_Service.opt
%config(noreplace) %{_sysconfdir}/tao/Naming_Service.conf

# ---------------- tao-cosevent ----------------

%files -n tao-cosevent
%defattr(-,root,root,-)

%{_bindir}/CosEvent_Service
%config %{_sysconfdir}/rc.d/init.d/CosEvent_Service
%dir %{_sysconfdir}/tao
%config(noreplace) %{_sysconfdir}/tao/CosEvent_Service.opt
%config(noreplace) %{_sysconfdir}/tao/CosEvent_Service.conf

# ---------------- tao-notify ----------------

%files -n tao-notify
%defattr(-,root,root,-)

%{_bindir}/Notify_Service
%config %{_sysconfdir}/rc.d/init.d/Notify_Service
%dir %{_sysconfdir}/tao
%config(noreplace) %{_sysconfdir}/tao/Notify_Service.opt
%config(noreplace) %{_sysconfdir}/tao/Notify_Service.conf

# ---------------- tao-trading ----------------

%files -n tao-trading
%defattr(-,root,root,-)

%{_bindir}/Trading_Service
%config %{_sysconfdir}/rc.d/init.d/Trading_Service
%dir %{_sysconfdir}/tao
%config(noreplace) %{_sysconfdir}/tao/Trading_Service.opt
%config(noreplace) %{_sysconfdir}/tao/Trading_Service.conf

# ---------------- tao-event ----------------

%files -n tao-event
%defattr(-,root,root,-)

%{_bindir}/Event_Service
%config %{_sysconfdir}/rc.d/init.d/Event_Service
%dir %{_sysconfdir}/tao
%config(noreplace) %{_sysconfdir}/tao/Event_Service.opt
%config(noreplace) %{_sysconfdir}/tao/Event_Service.conf

# ---------------- tao-concurrency ----------------

%files -n tao-concurrency
%defattr(-,root,root,-)

%{_bindir}/Concurrency_Service
%config %{_sysconfdir}/rc.d/init.d/Concurrency_Service
%dir %{_sysconfdir}/tao
%config(noreplace) %{_sysconfdir}/tao/Concurrency_Service.opt
%config(noreplace) %{_sysconfdir}/tao/Concurrency_Service.conf

# Read: true if _with_guilibs is defined, false if not defined.
%if %{?_with_guilibs:1}%{!?_with_guilibs:0}
# ---------------- tao-flresource ----------------
%files -n tao-flresource
%defattr(-,root,root,-)
%{_libdir}/libTAO_FlResource.so.%{TAOVERSO}

# ---------------- tao-flresource-devel ----------------
%files -n tao-flresource-devel
%defattr(-,root,root,-)
%{_libdir}/libTAO_FlResource.so
%dir %{_includedir}/tao
%{_includedir}/tao/FlResource/FlResource_Factory.h
%{_includedir}/tao/FlResource/FlResource_Loader.h
%{_includedir}/tao/FlResource/TAO_FlResource_Export.h

# ---------------- tao-qtresource ----------------
%files -n tao-qtresource
%defattr(-,root,root,-)
%{_libdir}/libTAO_QtResource.so.%{TAOVERSO}

# ---------------- tao-qtresource-devel ----------------
%files -n tao-qtresource-devel
%defattr(-,root,root,-)
%{_libdir}/libTAO_QtResource.so
%dir %{_includedir}/tao
%{_includedir}/tao/QtResource/QtResource_Factory.h
%{_includedir}/tao/QtResource/QtResource_Loader.h
%{_includedir}/tao/QtResource/TAO_QtResource_Export.h

# ---------------- tao-tkresource ----------------
%files -n tao-tkresource
%defattr(-,root,root,-)
%{_libdir}/libTAO_TkResource.so.%{TAOVERSO}

# ---------------- tao-tkresource-devel ----------------
%files -n tao-tkresource-devel
%defattr(-,root,root,-)
%{_libdir}/libTAO_TkResource.so
%dir %{_includedir}/tao
%{_includedir}/tao/TkResource/TkResource_Factory.h
%{_includedir}/tao/TkResource/TkResource_Loader.h
%{_includedir}/tao/TkResource/TAO_TkResource_Export.h

# ---------------- tao-xtresource ----------------
%files -n tao-xtresource
%defattr(-,root,root,-)
%{_libdir}/libTAO_XtResource.so.%{TAOVERSO}

# ---------------- tao-xtresource-devel ----------------
%files -n tao-xtresource-devel
%defattr(-,root,root,-)
%{_libdir}/libTAO_XtResource.so
%dir %{_includedir}/tao
%{_includedir}/tao/XtResource/XtResource_Factory.h
%{_includedir}/tao/XtResource/XtResource_Loader.h
%{_includedir}/tao/XtResource/TAO_XtResource_Export.h
%endif

# ================================================================
# changelog
# ================================================================

%changelog
* Sat Sep 22 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.6.1-1
- Updated to latest DOC group release (x.6.1).

* Mon Sep  3 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.6-1
- Updated to latest DOC group release (x.6).
- Combined 64bit patches into ace-tao-x86_64.patch.

* Wed Aug  1 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.10-1
- Updated to latest DOC group release (x.5.10).

* Sun Jul  1 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.9-1
- Updated to latest DOC group release (x.5.9).

* Sat May  5 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.8-1
- Updated to latest DOC group release (x.5.8).
- Added ACE_GCC_HAS_TEMPLATE_INSTANTIATION_VISIBILITY_ATTRS.

* Sat Mar 24 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.7-1
- Updated to latest DOC group release (x.5.7).

* Mon Feb 19 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.6-2
- Added SSLIOP refcount patch (DOC BUG 1506).

* Fri Feb  2 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.6-1
- Updated to latest DOC group release (x.5.6).

* Thu Jan 25 2007 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.5-1
- Updated to latest DOC group release (x.5.5).
- Adjusted paths to {Fl,Qt,Tk,Xt}Reactor headers.

* Sat Dec 16 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.4-2
- Defined ACE_HAS_EVENT_POLL config parameter.

* Wed Nov 29 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.4-1
- Updated to latest DOC group release (x.5.4).

* Mon Nov 20 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.3-3
- Improved obstack patch per Johnny Willemsen.

* Sat Nov 18 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.3-2
- Added obstack workaround for FC6 builds.
- Fixed IPV6 configuration patch.

* Tue Oct 10 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.3-1
- Updated to latest DOC group release (x.5.3).

* Tue Sep  5 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.2-2
- Added ACE_HAS_ICMP_SUPPORT to config.h
- Added patch to re-enable setting ssl verify mode.

* Wed Jul 12 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.2-1
- Updated to latest DOC group release (x.5.2).

* Sat Jun 24 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.1-4
- Added IPv6 support by default.

* Wed Jun 14 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.1-3
- Added x86_64 patch back in (required for GUI builds).

* Sun May 21 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.1-2
- Added aio64 patch for librt.so detection.

* Wed Apr 19 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5.1-1
- Updated to latest DOC group release (x.5.1).
- Added conditional (on by default) addition of
  ACE_HAS_REACTOR_NOTIFICATION_QUEUE to config.h.

* Sat Mar 25 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5-2
- Added Doug Schmidt's patches for gcc 4.1.0 type-punned warnings.
- Removed X11 build dependencies due to xorg package renaming.

* Tue Mar  7 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.5-1
- Updated to latest DOC group release (x.5)

* Wed Feb 22 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.10-1
- Updated to latest DOC group release (x.4.10)

* Sat Feb 11 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.9-2
- Created unversioned symlinks for svc.conf loadable shared objects
  in runtime packages.
- Now run mwc during rpmbuild even if _with_guilibs is not defined.
- Removed patch for fixed namespace bugs.

* Thu Feb  9 2006 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.9-1
- Updated to latest DOC group release (x.4.9)

* Fri Dec 23 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.8-1
- Added ace-tao-idl-preproc patch for IDL include path bug.

* Thu Dec 22 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.8-0
- Updated to the latest DOC group release (5.4.8)

* Fri Dec  9 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.7-1
- Added buildbits=64 macro for 64 bit archs.

* Mon Aug  8 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.7-0
- Updated to latest DOC group release (5.4.7)

* Fri Jun 10 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.6-0
- Updated to latest DOC group release (5.4.6)

* Sun May 15 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.5-0
- Updated to latest DOC group release (5.4.5)
- Removed TSS Cleanup patch (bug fixed in release).

* Sat Mar  5 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-5
- Fixed include directory uninstall cleanup for GUI reactor packages.
- Fixed installation to preserve header timestamps.

* Wed Mar  2 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-4
- Integrated Marek Brudka's GUI library additions.

* Thu Feb 24 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-3
- Changed name of spec, source rpm and patches to remove '+'.

* Sat Feb 19 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-2
- Fixed installed doc, header and debug source file permissions.

* Fri Feb 18 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-2
- Updated spec tags per Fedora PackagingHints wiki document.

* Thu Feb 17 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-1
- Added patch to rename gperf info menu entry to gperf-ace.
- Replaced TSS-Cleanup patch with candidate fixes from Dale Wilson.

* Wed Feb 16 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-1
- Macroed some absolute paths in the %files section.
- Added post and preun calls to install-info.

* Mon Feb 14 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-1
- Fixed BuildRequires entries.

* Sun Feb 13 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-1
- Added Giovanni Ferro's _extension macro for info and man pages.

* Thu Feb 10 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.4-0
- Updated to latest DOC group release (5.4.4).
- Removed idl-rootinc patch (fixed in distro).
- Removed orbdaemon patch (fixed in distro).
- Added libTAO_TMCast.so to ace package.

* Mon Feb  7 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.3-5
- Added /usr/include/ACEXML to explicit directory list.

* Sun Feb  6 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.3-4
- Fixed unfulfilled dependency in tao package for libTAO_IDL_FE.so
- Removed bidir-noassert patch, not needed.

* Mon Jan 31 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.3-4
- Added TSS Cleanup fixes patch (DOC bugzilla #2044)

* Mon Jan 17 2005 Andrew L. Shwaika <als@solvo.ru> - 5.4.3-3
- Add CORBA services

* Sat Jan 15 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.3-2
- Used ACE_GPERF to change name of installed gperf to gperf-ace.

* Mon Jan 10 2005 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.3-1
- Added bidir-noassert2 patch.

* Sat Dec 18 2004 Ken Sedgwick <ken+5a4@bonsai.com> - 5.4.2-0
- Initial build.
